@@ -3,6 +3,7 @@ Implements the async client that interacts with Customer.io's Track API using Si
 """
 import typing as t
 from datetime import datetime
+from typing import Optional
 from urllib.parse import quote
 
 from async_customerio.client_base import AsyncClientBase
@@ -32,10 +33,10 @@ class AsyncCustomerIO(AsyncClientBase):
         self,
         site_id: str,
         api_key: str,
-        host: str = None,
+        host: Optional[str] = None,
         region: Region = Regions.US,
-        port: int = None,
-        url_prefix: str = None,
+        port: Optional[int] = None,
+        url_prefix: Optional[str] = None,
         retries: int = 3,
         timeout: int = 10,
     ):
@@ -69,18 +70,18 @@ class AsyncCustomerIO(AsyncClientBase):
 
         return template.format(host=host.strip("/"), port=port, prefix=prefix.strip("/"))
 
-    async def identify(self, id_: t.Union[str, int], **attrs) -> None:
+    async def identify(self, identifier: t.Union[str, int], **attrs) -> None:
         """
         Identify a single customer by their unique id, and optionally add attributes.
 
-        :param id_: the unique value representing a person. The values you use to identify a person may be an
+        :param identifier: the unique value representing a person. The values you use to identify a person may be an
             ``id``, ``email`` address, or the ``cio_id`` (when updating people), depending on your workspace settings.
             When you reference people by ``cio_id``, you must prefix the value with ``cio_``.
         """
-        if not id_:
-            raise AsyncCustomerIOError("id_ cannot be blank in identify")
+        if not identifier:
+            raise AsyncCustomerIOError("identifier cannot be blank in identify")
         await self.send_request(
-            "PUT", join_url(self.base_url, self.CUSTOMER_ENDPOINT.format(id=id_)), json_payload=attrs
+            "PUT", join_url(self.base_url, self.CUSTOMER_ENDPOINT.format(id=identifier)), json_payload=attrs
         )
 
     async def track(self, customer_id: t.Union[str, int], name: str, **data) -> None:
@@ -273,8 +274,8 @@ class AsyncCustomerIO(AsyncClientBase):
         method: str,
         url: str,
         *,
-        json_payload: t.Dict[str, t.Any] = None,
-        headers: t.Dict[str, str] = None,
+        json_payload: Optional[t.Dict[str, t.Any]] = None,
+        headers: Optional[t.Dict[str, str]] = None,
         auth: t.Optional[t.Tuple[str, str]] = None
     ) -> t.Union[dict]:
         return await super().send_request(
